// This file was generated by gir (https://github.com/gtk-rs/gir)
// from
// from gir-files
// DO NOT EDIT

use glib::translate::*;

use crate::ffi;

#[doc(alias = "gly_gtk_frame_get_texture")]
pub fn frame_get_texture(frame: &gly::Frame) -> gdk::Texture {
    assert_initialized_main_thread!();
    unsafe { from_glib_full(ffi::gly_gtk_frame_get_texture(frame.to_glib_none().0)) }
}
